@@ -248,14 +248,20 @@ def root():
 @root.command()
 @click.option('-k', '--api-key', type=str)
 @click.option('-s', '--source', type=str)
-@click.option('-t', '--target', type=str)
+@click.argument('-t', '--target', type=str)
 def config(api_key, source, target):
+    global configs
     """Show and set configuration"""
     if not (api_key or source or target):
         print(' Source language:\t' + configs['SOURCE'])
-        print(' Yandex API key:\t' + ' '.join(configs['TARGET']))
-        print(' Target languages:\t' + configs['TRANSLATOR_KEY'])
+        print(' Target languages:\t' + ' '.join(configs['TARGET']))
+        print(' Yandex API key:\t' + configs['TRANSLATOR_KEY'])
         exit()
+    if api_key: configs['TRANSLATOR_KEY'] = api_key
+    if source: configs['SOURCE'] = source
+    if target: configs['TARGET'] = target.split(' ')
+    with open(os.path.expanduser('~') + '/' + 'tradocs.config.json', 'w+') as file:
+        json.dump(configs, file)
     re.purge
     exit()
 
